import fetch from 'node-fetch';
import checkTargetUrl from './check-target-url';
import { REPLICATION_STATE } from '@resolve-js/module-replication';

const getReplicationState = async ({
  targetApplicationUrl
}) => {
  const checkResult = checkTargetUrl(targetApplicationUrl);

  if (checkResult != null) {
    return checkResult;
  }

  const defaultValues = {
    paused: false,
    iterator: null,
    successEvent: null,
    locked: false
  };

  try {
    const response = await fetch(`${targetApplicationUrl}${REPLICATION_STATE.endpoint}`);
    const state = await response.json();

    if (response.status >= 400) {
      var _message;

      return {
        status: 'serviceError',
        statusData: {
          name: response.statusText,
          message: (_message = state.message) !== null && _message !== void 0 ? _message : response.statusText
        },
        ...defaultValues
      };
    }

    return state;
  } catch (error) {
    if (error.name === 'AbortError' || error.name === 'FetchError' || error.name === 'TypeError') {
      return {
        status: 'serviceError',
        statusData: {
          name: error.name,
          message: error.message,
          stack: error.stack ? error.stack : null
        },
        ...defaultValues
      };
    } else {
      return {
        status: 'error',
        statusData: {
          name: error.name,
          message: error.message,
          stack: error.stack ? error.stack : null
        },
        ...defaultValues
      };
    }
  }
};

export default getReplicationState;
//# sourceMappingURL=get-replication-state.js.map